@@ -124,7 +124,7 @@ def persist_lines(config, lines, table_cache=None, file_format_type: FileFormatT
         'last_executed_time': datetime.now(),
     }
     event_loop = setup_flush_task(time_schedule, records_to_load, row_count, stream_to_sync, config,
-                                  state, flushed_state)
+                                  state, flushed_state, archive_load_files_data)
 
     # Loop over lines from stdin
     for line in lines:
@@ -525,19 +525,19 @@ def flush_records(stream: str,
 
 
 def setup_flush_task(time_schedule, streams, row_count, stream_to_sync, config, state, flushed_state,
-                     filter_streams=None) -> AbstractEventLoop:
+                     archive_load_files_data, filter_streams=None) -> AbstractEventLoop:
     event_loop = asyncio.new_event_loop()
     Thread(target=start_background_loop, args=(
         event_loop,), daemon=True).start()
     asyncio.run_coroutine_threadsafe(
         flush_task(time_schedule, streams, row_count, stream_to_sync,
-                   config, state, flushed_state, filter_streams),
+                   config, state, flushed_state, archive_load_files_data, filter_streams),
         event_loop)
     return event_loop
 
 
 async def flush_task(time_schedule, streams, row_count, stream_to_sync, config, state, flushed_state,
-                     filter_streams=None) -> None:
+                     archive_load_files_data, filter_streams=None) -> None:
     while True:
         timedelta = datetime.now() - time_schedule['last_executed_time']
         if (
@@ -547,7 +547,7 @@ async def flush_task(time_schedule, streams, row_count, stream_to_sync, config,
         ):
             # flush all streams one last time, delete records if needed, reset counts and then emit current state.
             flushed_state = flush_streams(streams, row_count, stream_to_sync, config, state, flushed_state,
-                                          filter_streams)
+                                          archive_load_files_data, filter_streams)
             # emit latest state
             emit_state(copy.deepcopy(flushed_state))
             time_schedule['last_executed_time'] = datetime.now()
