@@ -418,13 +418,15 @@ class DbSync:
         self.upload_client.copy_object(
             copy_source, archive_bucket, prefixed_archive_key, s3_archive_metadata)
 
-    def get_stage_name(self): # TODO: If stage needed at later stage, take name defined from user
+    # TODO: If stage needed at later stage, take name defined from user
+    def get_stage_name(self, stream):
         """Generate snowflake stage name"""
         stage = self.connection_config.get('stage', None)
         if stage:
             return stage
 
-        table_name = self.table_name(self.connection_config.get('target_table'), False, without_schema=True)
+        table_name = self.table_name(self.connection_config.get(
+            'target_table'), False, without_schema=True)
         return f"{self.schema_name}.%{table_name}"
 
     def load_file(self, s3_key, count, size_bytes):
@@ -457,7 +459,8 @@ class DbSync:
             except Exception as ex:
                 self.logger.error(
                     'Error while executing MERGE query for table "%s" in stream "%s"',
-                    self.table_name(self.connection_config.get('target_table'), False), stream
+                    self.table_name(self.connection_config.get(
+                        'target_table'), False), stream
                 )
                 raise ex
 
@@ -475,7 +478,8 @@ class DbSync:
             except Exception as ex:
                 self.logger.error(
                     'Error while executing COPY query for table "%s" in stream "%s"',
-                    self.table_name(self.connection_config.get('target_table'), False), stream
+                    self.table_name(self.connection_config.get(
+                        'target_table'), False), stream
                 )
                 raise ex
 
@@ -493,7 +497,8 @@ class DbSync:
         with self.open_connection() as connection:
             with connection.cursor(snowflake.connector.DictCursor) as cur:
                 merge_sql = self.file_format.formatter.create_merge_sql(
-                    table_name=self.table_name(self.connection_config.get('target_table'), False),
+                    table_name=self.table_name(
+                        self.connection_config.get('target_table'), False),
                     stage_name=self.get_stage_name(stream),
                     s3_key=s3_key,
                     file_format_name=self.connection_config['file_format'],
@@ -515,7 +520,8 @@ class DbSync:
         with self.open_connection() as connection:
             with connection.cursor(snowflake.connector.DictCursor) as cur:
                 copy_sql = self.file_format.formatter.create_copy_sql(
-                    table_name=self.table_name(self.connection_config.get('target_table'), False),
+                    table_name=self.table_name(
+                        self.connection_config.get('target_table'), False),
                     stage_name=self.get_stage_name(stream),
                     s3_key=s3_key,
                     file_format_name=self.connection_config['file_format'],
@@ -588,7 +594,8 @@ class DbSync:
 
     def delete_rows(self, stream):
         """Hard delete rows from target table"""
-        table = self.table_name(self.connection_config.get('target_table'), False)
+        table = self.table_name(
+            self.connection_config.get('target_table'), False)
         query = f"DELETE FROM {table} WHERE _sdc_deleted_at IS NOT NULL"
         self.logger.info("Deleting rows from '%s' table... %s", table, query)
         self.logger.info('DELETE %d', len(self.query(query)))
@@ -719,7 +726,8 @@ class DbSync:
         """Adds required but not existing columns the target table according to the schema"""
         stream_schema_message = self.stream_schema_message
         stream = stream_schema_message['stream']
-        table_name = self.table_name(self.connection_config.get('target_table'), False, True)
+        table_name = self.table_name(
+            self.connection_config.get('target_table'), False, True)
         all_table_columns = []
 
         if self.table_cache:
@@ -784,7 +792,8 @@ class DbSync:
 
     def version_column(self, column_name, stream):
         """Versions a column in an existing table"""
-        p_table_name = self.table_name(self.connection_config.get('target_table'), False)
+        p_table_name = self.table_name(
+            self.connection_config.get('target_table'), False)
         p_column_name = column_name.replace("\"", "")
         p_ver_time = time.strftime("%Y%m%d_%H%M")
 
@@ -803,7 +812,8 @@ class DbSync:
         stream_schema_message = self.stream_schema_message
         stream = stream_schema_message['stream']
         table_name = self.table_name(stream, False, True)
-        table_name_with_schema = self.table_name(self.connection_config.get('target_table'), False)
+        table_name_with_schema = self.table_name(
+            self.connection_config.get('target_table'), False)
 
         if self.table_cache:
             found_tables = list(filter(lambda x: x['SCHEMA_NAME'] == self.schema_name.upper() and
